==> gatling-core-3.5.1-sources.jar: io/gatling/core/check/css/Lagarto.scala <==
/*
 * Copyright 2011-2021 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.core.check.css

import com.typesafe.scalalogging.StrictLogging
import jodd.lagarto.{ LagartoParser, LagartoParserConfig }
import jodd.lagarto.dom.{ LagartoDOMBuilder, LagartoDomBuilderConfig }

object Lagarto extends StrictLogging {

  private val ParserConfig =
    new LagartoParserConfig()
      .setEnableConditionalComments(false)
      .setEnableRawTextModes(false)

  private val DomBuilderConfig = {
    val config = new LagartoDomBuilderConfig()
    config.setParserConfig(ParserConfig)
    if (logger.underlying.isDebugEnabled) {
      config.setErrorLogConsumer { case (logger, message) => logger.debug(message) }
    } else {
      config.setErrorLogEnabled(false)
    }
    config
  }

  def newLagartoDomBuilder: LagartoDOMBuilder =
    new LagartoDOMBuilder(DomBuilderConfig)

  def newLagartoParser(chars: Array[Char]): LagartoParser =
    new LagartoParser(ParserConfig, chars)
}

==> gatling-core-3.6.1-sources.jar: io/gatling/core/check/css/Lagarto.scala <==
/*
 * Copyright 2011-2021 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.core.check.css

import com.typesafe.scalalogging.StrictLogging
import jodd.lagarto.{ LagartoParser, LagartoParserConfig }
import jodd.lagarto.dom.{ LagartoDOMBuilder, LagartoDomBuilderConfig }

object Lagarto extends StrictLogging {

  private val ParserConfig =
    new LagartoParserConfig()
      .setEnableConditionalComments(false)
      .setEnableRawTextModes(false)

  private val DomBuilderConfig = {
    val config = new LagartoDomBuilderConfig()
    config.setParserConfig(ParserConfig)
    if (logger.underlying.isDebugEnabled) {
      config.setErrorLogConsumer((logger, message) => logger.debug(message))
    } else {
      config.setErrorLogEnabled(false)
    }
    config
  }

  def newLagartoDomBuilder: LagartoDOMBuilder =
    new LagartoDOMBuilder(DomBuilderConfig)

  def newLagartoParser(chars: Array[Char]): LagartoParser =
    new LagartoParser(ParserConfig, chars)
}
